pub fn derive_packet_tag(secret: &SecretKey) -> Result<PacketTag>Expand description
Derives the packet tag used during packet construction by expanding the given secret.
pub fn derive_packet_tag(secret: &SecretKey) -> Result<PacketTag>Derives the packet tag used during packet construction by expanding the given secret.